summaryrefslogtreecommitdiffstats
path: root/tests/auto/qhttp
diff options
context:
space:
mode:
authorJason Barron <jbarron@trolltech.com>2009-08-13 09:24:47 +0200
committerJason Barron <jbarron@trolltech.com>2009-08-13 10:27:51 +0200
commit13cbcc0ddca0fdd5be9ede09052d31785c1e4d55 (patch)
treeb647be5699145ccae1545096aba5c495d96f8eb5 /tests/auto/qhttp
parent081078137a6fbc85d6be1437f6afc1d60e4f75f9 (diff)
parentde088b5a7f7b57e568399334667b14bfc9e7b893 (diff)
Merge commit 'qt/master'
Conflicts: examples/opengl/samplebuffers/glwidget.cpp src/corelib/io/qfsfileengine_unix.cpp src/corelib/kernel/qobject.cpp src/corelib/tools/qsharedpointer.cpp src/gui/gui.pro tests/auto/qhttp/tst_qhttp.cpp tests/auto/qkeyevent/tst_qkeyevent.cpp
Diffstat (limited to 'tests/auto/qhttp')
-rw-r--r--tests/auto/qhttp/dummyserver.h2
-rw-r--r--tests/auto/qhttp/tst_qhttp.cpp18
2 files changed, 10 insertions, 10 deletions
diff --git a/tests/auto/qhttp/dummyserver.h b/tests/auto/qhttp/dummyserver.h
index a4effea8d9..8b9004d06e 100644
--- a/tests/auto/qhttp/dummyserver.h
+++ b/tests/auto/qhttp/dummyserver.h
@@ -34,7 +34,7 @@
** met: http://www.gnu.org/copyleft/gpl.html.
**
** If you are unsure which license is appropriate for your use, please
-** contact the sales department at http://www.qtsoftware.com/contact.
+** contact the sales department at http://qt.nokia.com/contact.
** $QT_END_LICENSE$
**
****************************************************************************/
diff --git a/tests/auto/qhttp/tst_qhttp.cpp b/tests/auto/qhttp/tst_qhttp.cpp
index 37ce256731..b0835ace1b 100644
--- a/tests/auto/qhttp/tst_qhttp.cpp
+++ b/tests/auto/qhttp/tst_qhttp.cpp
@@ -34,7 +34,7 @@
** met: http://www.gnu.org/copyleft/gpl.html.
**
** If you are unsure which license is appropriate for your use, please
-** contact the sales department at http://www.qtsoftware.com/contact.
+** contact the sales department at http://qt.nokia.com/contact.
** $QT_END_LICENSE$
**
****************************************************************************/
@@ -329,8 +329,8 @@ void tst_QHttp::get_data()
QTest::newRow( QString("failprot_02_%1").arg(i).toLatin1() ) << QtNetworkSettings::serverName() << 80u
<< QString("qtest/rfc3252.txt") << 1 << 400 << QByteArray() << (bool)(i==1);
//doc.trolltech.com uses transfer-encoding=chunked
/* doc.trolltech.com no longer seams to be using chuncked encodig.
QTest::newRow( QString("chunked_01_%1").arg(i).toLatin1() ) << QString("test.troll.no") << 80u
<< QString("/") << 1 << 200 << trolltech << (bool)(i==1);
*/
@@ -430,8 +430,8 @@ void tst_QHttp::head_data()
QTest::newRow( "failprot_02" ) << QtNetworkSettings::serverName() << 80u
<< QString("qtest/rfc3252.txt") << 1 << 400 << 0u;
- /* doc.trolltech.com no longer seams to be using chuncked encodig.
- QTest::newRow( "chunked_01" ) << QString("doc.trolltech.com") << 80u
+ /* qt.nokia.com/doc no longer seams to be using chuncked encodig.
+ QTest::newRow( "chunked_01" ) << QString("qt.nokia.com/doc") << 80u
<< QString("/index.html") << 1 << 200 << 0u;
*/
QTest::newRow( "chunked_02" ) << QtNetworkSettings::serverName() << 80u
@@ -751,13 +751,13 @@ void tst_QHttp::proxy_data()
QTest::addColumn<QString>("proxypass");
QTest::newRow("qt-test-server") << QtNetworkSettings::serverName() << 3128
- << QString::fromLatin1("www.qtsoftware.com") << QString::fromLatin1("/")
+ << QString::fromLatin1("qt.nokia.com") << QString::fromLatin1("/")
<< QString::fromLatin1("") << QString::fromLatin1("");
QTest::newRow("qt-test-server pct") << QtNetworkSettings::serverName() << 3128
- << QString::fromLatin1("www.qtsoftware.com") << QString::fromLatin1("/%64eveloper")
+ << QString::fromLatin1("qt.nokia.com") << QString::fromLatin1("/%64eveloper")
<< QString::fromLatin1("") << QString::fromLatin1("");
QTest::newRow("qt-test-server-basic") << QtNetworkSettings::serverName() << 3129
- << QString::fromLatin1("www.qtsoftware.com") << QString::fromLatin1("/")
+ << QString::fromLatin1("qt.nokia.com") << QString::fromLatin1("/")
<< QString::fromLatin1("qsockstest") << QString::fromLatin1("password");
#if 0
@@ -765,7 +765,7 @@ void tst_QHttp::proxy_data()
// the tst_QHttp class is too strict to handle the byte counts sent by dataSendProgress
// So don't run this test:
QTest::newRow("qt-test-server-ntlm") << QtNetworkSettings::serverName() << 3130
- << QString::fromLatin1("www.qtsoftware.com") << QString::fromLatin1("/")
+ << QString::fromLatin1("qt.nokia.com") << QString::fromLatin1("/")
<< QString::fromLatin1("qsockstest") << QString::fromLatin1("password");
#endif
}
@@ -329,8 +329,8 @@ void tst_QHttp::get_data()
QTest::newRow( QString("failprot_02_%1").arg(i).toLatin1() ) << QtNetworkSettings::serverName() << 80u
<< QString("qtest/rfc3252.txt") << 1 << 400 << QByteArray() << (bool)(i==1);
- //doc.trolltech.com uses transfer-encoding=chunked
- /* doc.trolltech.com no longer seams to be using chuncked encodig.
+ // qt.nokia.com/doc uses transfer-encoding=chunked
+ /* qt.nokia.com/doc no longer seams to be using chuncked encodig.
QTest::newRow( QString("chunked_01_%1").arg(i).toLatin1() ) << QString("test.troll.no") << 80u
<< QString("/") << 1 << 200 << trolltech << (bool)(i==1);